@@ -25,7 +25,7 @@ from nwmanager import NetworkManager
 import dbus.service
 import dbus.mainloop.qt
 
-__version__ = '0.0.18'
+__version__ = '0.0.19'
 
 #Here is the installation of the hook. Each time a untrapped/unmanaged exception will
 #happen my_excepthook will be called.
@@ -34,44 +34,11 @@ def install_excepthook(app_name,app_version):
     APP_NAME = 'Khweeteur'
     APP_VERSION = __version__
 
-    def do_report(error):
-        import urllib2
-        import urllib
-        if ((QMessageBox.question(None,
-            "Khweeteur Crash Report",
-            "Report this bug on bug tracker ?",
-            QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
-            url = 'http://khertan.net/report.php' # write ur URL here
-            values = {
-                  'project' : APP_NAME.lower(),
-                  'version':APP_VERSION,
-                  'description':error,
-                  }    
-            try:
-                data = urllib.urlencode(values)
-                req = urllib2.Request(url, data)
-                response = urllib2.urlopen(req)
-                the_page = response.read()
-            except Exception, detail:
-                QMessageBox.question(None,
-                "Khweeteur Crash Report",
-                "An error occur during the report : %s" % detail,
-                QMessageBox.Close)
-                return False
-    
-            if 'Your report have been successfully stored' in the_page:
-                QMessageBox.question(None,
-                "Khweeteur Crash Report",
-                "%s" % the_page,
-                QMessageBox.Close)
-                return True
-            else:
-                QMessageBox.question(None,
-                "Khweeteur Crash Report",
-                "%s" % the_page,
-                QMessageBox.Close)
-                return False
-                
+    def write_report(error):
+        filename = os.path.join(CACHE_PATH,'crash_report')
+        output = open(filename, 'wb')
+        pickle.dump(error, output)
+        output.close()
         
     def my_excepthook(exctype, value, tb):
         #traceback give us all the errors information message like the method, file line ... everything like
@@ -80,7 +47,7 @@ def install_excepthook(app_name,app_version):
         s = ''.join(traceback.format_exception(exctype, value, tb))
         print 'Except hook called : %s' % (s)
         formatted_text = "%s Version %s\nTrace : %s\nComments : " % (APP_NAME, APP_VERSION, s)
-        do_report(formatted_text)
+        write_report(formatted_text)
         
     sys.excepthook = my_excepthook
         
@@ -307,7 +274,7 @@ class KhweetsModel(QAbstractListModel):
         self._avatars = {}
         self._new_counter = 0
         self.now = time.time()
-
+        
         self.display_screenname = False
         self.display_timestamp = False
         self.display_avatar = True
@@ -807,6 +774,11 @@ class KhweeteurWin(QMainWindow):
         self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
         self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
         self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
+
+            
+        QTimer.singleShot(200, self.justAfterInit)
+        
+    def justAfterInit(self):
         self.nw = NetworkManager(self.refresh_timeline)
         self.notifications = KhweeteurNotification()
 
@@ -970,7 +942,9 @@ class KhweeteurWin(QMainWindow):
         
         if (counter>0) and (self.settings.value('useNotification').toBool()) and not (self.isActiveWindow()):
             if self.search_keyword:
-                self.notifications.notify_search(self.search_keyword,'Khweeteur',self.search_keyword+': '+str(counter)+' new tweet(s)',count=counter)
+                pass
+                #Disable notification for search
+                #self.notifications.notify_search(self.search_keyword,'Khweeteur',self.search_keyword+': '+str(counter)+' new tweet(s)',count=counter)
             else:
                 self.notifications.notify('Khweeteur',str(counter)+' new tweet(s)',count=counter)
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
@@ -1112,9 +1086,53 @@ class Khweeteur(QApplication):
         self.dbus_object = KhweeteurDBus(session_bus, '/net/khertan/khweeteur')        
         self.run()
         
+    def crash_report(self):
+        if os.path.isfile(os.path.join(CACHE_PATH,'crash_report')):
+            import urllib2
+            import urllib
+            if ((QMessageBox.question(None,
+                "Khweeteur Crash Report",
+                "An error occur on khweeteur in the previous launch. Report this bug on the bug tracker ?",
+                QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
+                url = 'http://khertan.net/report.php' # write ur URL here
+                values = {
+                      'project' : APP_NAME.lower(),
+                      'version':APP_VERSION,
+                      'description':error,
+                      }    
+                try:
+                    data = urllib.urlencode(values)
+                    req = urllib2.Request(url, data)
+                    response = urllib2.urlopen(req)
+                    the_page = response.read()
+                except Exception, detail:
+                    QMessageBox.question(None,
+                    "Khweeteur Crash Report",
+                    "An error occur during the report : %s" % detail,
+                    QMessageBox.Close)
+                    return False
+
+                if 'Your report have been successfully stored' in the_page:
+                    QMessageBox.question(None,
+                    "Khweeteur Crash Report",
+                    "%s" % the_page,
+                    QMessageBox.Close)
+                    return True
+                else:
+                    QMessageBox.question(None,
+                    "Khweeteur Crash Report",
+                    "%s" % the_page,
+                    QMessageBox.Close)
+                    return False
+            try:
+                os.remove(os.path.join(CACHE_PATH,'crash_report'))
+            except:
+                pass
+                
     def run(self):
         self.win = KhweeteurWin()
         self.dbus_object.attach_win(self.win)
+        self.crash_report()
         self.win.show()
         sys.exit(self.exec_())
 
